==> scanning-plugin-0.17.0-sources.jar: com/estimote/scanning_plugin/dagger/ScanSettingsTransformersModule.kt <==
package com.estimote.scanning_plugin.dagger

import android.annotation.TargetApi
import android.bluetooth.BluetoothAdapter
import android.bluetooth.le.ScanFilter
import android.os.Build
import com.estimote.scanning_plugin.packet_provider.scanner.filter_transformers.*
import com.estimote.scanning_plugin.packet_provider.scanner.settings_transformers.ScanSettingsTransformerProvider
import com.estimote.scanning_plugin.settings.ScanSettingsVisitor
import dagger.Module
import dagger.Provides

@Module
internal class ScanSettingsTransformersModule(private val androidApiVersion: Int,
                                              private val manufacturerId: String) {

    @TargetApi(Build.VERSION_CODES.LOLLIPOP)
    @Provides
    @EstimoteScanningSdkScope
    fun provideEstimoteSettingsToFilterTransformer(bluetoothAdapter: BluetoothAdapter?): ScanSettingsVisitor<@JvmWildcard List<ScanFilter>> =
            if (bluetoothAdapter != null && bluetoothAdapter.isOffloadedFilteringSupported) {
                DefaultScanFiltersTransformer(
                        ToIBeaconFilterTransformer(HardwareFilterBuilderFactory()),
                        ToEddystoneFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                        ToEstimoteTelemetryFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                        ToEstimoteLocationFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                        ToEstimoteMeshFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                        ToMirrorFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                        ToUwbFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                        ToNearableFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                        ToConfigurableDeviceFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                        ToEstimoteSecureFilterTransformers(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                        ToEstimoteRescueFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig())
                        )
            } else {
                NoScanFiltersTransformer()
            }

    @Provides
    @EstimoteScanningSdkScope
    fun provideScanSettingsTransformerProvider(): ScanSettingsTransformerProvider = ScanSettingsTransformerProvider(androidApiVersion, manufacturerId)
}

==> scanning-plugin-0.19.0-sources.jar: com/estimote/scanning_plugin/dagger/ScanSettingsTransformersModule.kt <==
package com.estimote.scanning_plugin.dagger

import android.annotation.TargetApi
import android.bluetooth.BluetoothAdapter
import android.bluetooth.le.ScanFilter
import android.os.Build
import com.estimote.scanning_plugin.packet_provider.scanner.filter_transformers.*
import com.estimote.scanning_plugin.packet_provider.scanner.settings_transformers.ScanSettingsTransformerProvider
import com.estimote.scanning_plugin.settings.ScanSettingsVisitor
import dagger.Module
import dagger.Provides

@Module
internal class ScanSettingsTransformersModule(private val androidApiVersion: Int,
                                              private val manufacturerId: String) {

    @TargetApi(Build.VERSION_CODES.LOLLIPOP)
    @Provides
    @EstimoteScanningSdkScope
    fun provideEstimoteSettingsToFilterTransformer(bluetoothAdapter: BluetoothAdapter?): ScanSettingsVisitor<@JvmWildcard List<ScanFilter>> =
            if (bluetoothAdapter != null && bluetoothAdapter.isOffloadedFilteringSupported) {
                DefaultScanFiltersTransformer(
                        ToIBeaconFilterTransformer(HardwareFilterBuilderFactory()),
                        ToEddystoneFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                        ToEstimoteTelemetryFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                        ToEstimoteLocationFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                        ToEstimoteMeshFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                        ToMirrorFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                        ToUwbFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                        ToNearableFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                        ToConfigurableDeviceFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                        ToEstimoteSecureFilterTransformers(HardwareFilterBuilderFactory(), ServicesUuidConfig()),
                        ToEstimoteRescueFilterTransformer(HardwareFilterBuilderFactory(), ServicesUuidConfig())
                        )
            } else {
                NoScanFiltersTransformer()
            }

    @TargetApi(Build.VERSION_CODES.LOLLIPOP)
    @Provides
    @EstimoteScanningSdkScope
    fun provideScanSettingsTransformerProvider(bluetoothAdapter: BluetoothAdapter?): ScanSettingsTransformerProvider =
            ScanSettingsTransformerProvider(androidApiVersion, manufacturerId, bluetoothAdapter?.isOffloadedScanBatchingSupported ?: false)
}
